# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/evm/v1/query.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.cosmos.base.query.v1beta1 import pagination_pb2 as cosmos_dot_base_dot_query_dot_v1beta1_dot_pagination__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from pyinjective.proto.injective.evm.v1 import log_pb2 as injective_dot_evm_dot_v1_dot_log__pb2
from pyinjective.proto.injective.evm.v1 import params_pb2 as injective_dot_evm_dot_v1_dot_params__pb2
from pyinjective.proto.injective.evm.v1 import trace_config_pb2 as injective_dot_evm_dot_v1_dot_trace__config__pb2
from pyinjective.proto.injective.evm.v1 import tx_pb2 as injective_dot_evm_dot_v1_dot_tx__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cinjective/evm/v1/query.proto\x12\x10injective.evm.v1\x1a*cosmos/base/query/v1beta1/pagination.proto\x1a\x14gogoproto/gogo.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ainjective/evm/v1/log.proto\x1a\x1dinjective/evm/v1/params.proto\x1a#injective/evm/v1/trace_config.proto\x1a\x19injective/evm/v1/tx.proto\"9\n\x13QueryAccountRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"c\n\x14QueryAccountResponse\x12\x18\n\x07\x62\x61lance\x18\x01 \x01(\tR\x07\x62\x61lance\x12\x1b\n\tcode_hash\x18\x02 \x01(\tR\x08\x63odeHash\x12\x14\n\x05nonce\x18\x03 \x01(\x04R\x05nonce\"?\n\x19QueryCosmosAccountRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x86\x01\n\x1aQueryCosmosAccountResponse\x12%\n\x0e\x63osmos_address\x18\x01 \x01(\tR\rcosmosAddress\x12\x1a\n\x08sequence\x18\x02 \x01(\x04R\x08sequence\x12%\n\x0e\x61\x63\x63ount_number\x18\x03 \x01(\x04R\raccountNumber\"K\n\x1cQueryValidatorAccountRequest\x12!\n\x0c\x63ons_address\x18\x01 \x01(\tR\x0b\x63onsAddress:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x8b\x01\n\x1dQueryValidatorAccountResponse\x12\'\n\x0f\x61\x63\x63ount_address\x18\x01 \x01(\tR\x0e\x61\x63\x63ountAddress\x12\x1a\n\x08sequence\x18\x02 \x01(\x04R\x08sequence\x12%\n\x0e\x61\x63\x63ount_number\x18\x03 \x01(\x04R\raccountNumber\"9\n\x13QueryBalanceRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"0\n\x14QueryBalanceResponse\x12\x18\n\x07\x62\x61lance\x18\x01 \x01(\tR\x07\x62\x61lance\"K\n\x13QueryStorageRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\",\n\x14QueryStorageResponse\x12\x14\n\x05value\x18\x01 \x01(\tR\x05value\"6\n\x10QueryCodeRequest\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\'\n\x11QueryCodeResponse\x12\x12\n\x04\x63ode\x18\x01 \x01(\x0cR\x04\x63ode\"z\n\x12QueryTxLogsRequest\x12\x12\n\x04hash\x18\x01 \x01(\tR\x04hash\x12\x46\n\npagination\x18\x02 \x01(\x0b\x32&.cosmos.base.query.v1beta1.PageRequestR\npagination:\x08\x88\xa0\x1f\x00\xe8\xa0\x1f\x00\"\x89\x01\n\x13QueryTxLogsResponse\x12)\n\x04logs\x18\x01 \x03(\x0b\x32\x15.injective.evm.v1.LogR\x04logs\x12G\n\npagination\x18\x02 \x01(\x0b\x32\'.cosmos.base.query.v1beta1.PageResponseR\npagination\"\x14\n\x12QueryParamsRequest\"M\n\x13QueryParamsResponse\x12\x36\n\x06params\x18\x01 \x01(\x0b\x32\x18.injective.evm.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"\xd5\x01\n\x0e\x45thCallRequest\x12\x12\n\x04\x61rgs\x18\x01 \x01(\x0cR\x04\x61rgs\x12\x17\n\x07gas_cap\x18\x02 \x01(\x04R\x06gasCap\x12]\n\x10proposer_address\x18\x03 \x01(\x0c\x42\x32\xfa\xde\x1f.github.com/cosmos/cosmos-sdk/types.ConsAddressR\x0fproposerAddress\x12\x19\n\x08\x63hain_id\x18\x04 \x01(\x03R\x07\x63hainId\x12\x1c\n\toverrides\x18\x05 \x01(\x0cR\toverrides\"T\n\x13\x45stimateGasResponse\x12\x10\n\x03gas\x18\x01 \x01(\x04R\x03gas\x12\x10\n\x03ret\x18\x02 \x01(\x0cR\x03ret\x12\x19\n\x08vm_error\x18\x03 \x01(\tR\x07vmError\"\xe0\x03\n\x13QueryTraceTxRequest\x12\x31\n\x03msg\x18\x01 \x01(\x0b\x32\x1f.injective.evm.v1.MsgEthereumTxR\x03msg\x12@\n\x0ctrace_config\x18\x03 \x01(\x0b\x32\x1d.injective.evm.v1.TraceConfigR\x0btraceConfig\x12\x43\n\x0cpredecessors\x18\x04 \x03(\x0b\x32\x1f.injective.evm.v1.MsgEthereumTxR\x0cpredecessors\x12!\n\x0c\x62lock_number\x18\x05 \x01(\x03R\x0b\x62lockNumber\x12\x1d\n\nblock_hash\x18\x06 \x01(\tR\tblockHash\x12\x43\n\nblock_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\tblockTime\x12]\n\x10proposer_address\x18\x08 \x01(\x0c\x42\x32\xfa\xde\x1f.github.com/cosmos/cosmos-sdk/types.ConsAddressR\x0fproposerAddress\x12\x19\n\x08\x63hain_id\x18\t \x01(\x03R\x07\x63hainIdJ\x04\x08\x02\x10\x03R\x08tx_index\"*\n\x14QueryTraceTxResponse\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\"\x87\x03\n\x15QueryTraceCallRequest\x12\x12\n\x04\x61rgs\x18\x01 \x01(\x0cR\x04\x61rgs\x12\x17\n\x07gas_cap\x18\x02 \x01(\x04R\x06gasCap\x12]\n\x10proposer_address\x18\x03 \x01(\x0c\x42\x32\xfa\xde\x1f.github.com/cosmos/cosmos-sdk/types.ConsAddressR\x0fproposerAddress\x12@\n\x0ctrace_config\x18\x04 \x01(\x0b\x32\x1d.injective.evm.v1.TraceConfigR\x0btraceConfig\x12!\n\x0c\x62lock_number\x18\x05 \x01(\x03R\x0b\x62lockNumber\x12\x1d\n\nblock_hash\x18\x06 \x01(\tR\tblockHash\x12\x43\n\nblock_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\tblockTime\x12\x19\n\x08\x63hain_id\x18\x08 \x01(\x03R\x07\x63hainId\",\n\x16QueryTraceCallResponse\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\"\x8e\x03\n\x16QueryTraceBlockRequest\x12\x31\n\x03txs\x18\x01 \x03(\x0b\x32\x1f.injective.evm.v1.MsgEthereumTxR\x03txs\x12@\n\x0ctrace_config\x18\x03 \x01(\x0b\x32\x1d.injective.evm.v1.TraceConfigR\x0btraceConfig\x12!\n\x0c\x62lock_number\x18\x05 \x01(\x03R\x0b\x62lockNumber\x12\x1d\n\nblock_hash\x18\x06 \x01(\tR\tblockHash\x12\x43\n\nblock_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x08\xc8\xde\x1f\x00\x90\xdf\x1f\x01R\tblockTime\x12]\n\x10proposer_address\x18\x08 \x01(\x0c\x42\x32\xfa\xde\x1f.github.com/cosmos/cosmos-sdk/types.ConsAddressR\x0fproposerAddress\x12\x19\n\x08\x63hain_id\x18\t \x01(\x03R\x07\x63hainId\"-\n\x17QueryTraceBlockResponse\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\"\x15\n\x13QueryBaseFeeRequest\"L\n\x14QueryBaseFeeResponse\x12\x34\n\x08\x62\x61se_fee\x18\x01 \x01(\tB\x19\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x07\x62\x61seFee2\xf6\r\n\x05Query\x12\x85\x01\n\x07\x41\x63\x63ount\x12%.injective.evm.v1.QueryAccountRequest\x1a&.injective.evm.v1.QueryAccountResponse\"+\x82\xd3\xe4\x93\x02%\x12#/injective/evm/v1/account/{address}\x12\x9e\x01\n\rCosmosAccount\x12+.injective.evm.v1.QueryCosmosAccountRequest\x1a,.injective.evm.v1.QueryCosmosAccountResponse\"2\x82\xd3\xe4\x93\x02,\x12*/injective/evm/v1/cosmos_account/{address}\x12\xaf\x01\n\x10ValidatorAccount\x12..injective.evm.v1.QueryValidatorAccountRequest\x1a/.injective.evm.v1.QueryValidatorAccountResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/injective/evm/v1/validator_account/{cons_address}\x12\x86\x01\n\x07\x42\x61lance\x12%.injective.evm.v1.QueryBalanceRequest\x1a&.injective.evm.v1.QueryBalanceResponse\",\x82\xd3\xe4\x93\x02&\x12$/injective/evm/v1/balances/{address}\x12\x8b\x01\n\x07Storage\x12%.injective.evm.v1.QueryStorageRequest\x1a&.injective.evm.v1.QueryStorageResponse\"1\x82\xd3\xe4\x93\x02+\x12)/injective/evm/v1/storage/{address}/{key}\x12z\n\x04\x43ode\x12\".injective.evm.v1.QueryCodeRequest\x1a#.injective.evm.v1.QueryCodeResponse\")\x82\xd3\xe4\x93\x02#\x12!/injective/evm/v1/codes/{address}\x12w\n\x06Params\x12$.injective.evm.v1.QueryParamsRequest\x1a%.injective.evm.v1.QueryParamsResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/injective/evm/v1/params\x12x\n\x07\x45thCall\x12 .injective.evm.v1.EthCallRequest\x1a\'.injective.evm.v1.MsgEthereumTxResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/injective/evm/v1/eth_call\x12~\n\x0b\x45stimateGas\x12 .injective.evm.v1.EthCallRequest\x1a%.injective.evm.v1.EstimateGasResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/injective/evm/v1/estimate_gas\x12|\n\x07TraceTx\x12%.injective.evm.v1.QueryTraceTxRequest\x1a&.injective.evm.v1.QueryTraceTxResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/injective/evm/v1/trace_tx\x12\x88\x01\n\nTraceBlock\x12(.injective.evm.v1.QueryTraceBlockRequest\x1a).injective.evm.v1.QueryTraceBlockResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/injective/evm/v1/trace_block\x12\x84\x01\n\tTraceCall\x12\'.injective.evm.v1.QueryTraceCallRequest\x1a(.injective.evm.v1.QueryTraceCallResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/injective/evm/v1/trace_call\x12|\n\x07\x42\x61seFee\x12%.injective.evm.v1.QueryBaseFeeRequest\x1a&.injective.evm.v1.QueryBaseFeeResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/injective/evm/v1/base_feeB\xcf\x01\n\x14\x63om.injective.evm.v1B\nQueryProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\xa2\x02\x03IEX\xaa\x02\x10Injective.Evm.V1\xca\x02\x10Injective\\Evm\\V1\xe2\x02\x1cInjective\\Evm\\V1\\GPBMetadata\xea\x02\x12Injective::Evm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.evm.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective.evm.v1B\nQueryProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\242\002\003IEX\252\002\020Injective.Evm.V1\312\002\020Injective\\Evm\\V1\342\002\034Injective\\Evm\\V1\\GPBMetadata\352\002\022Injective::Evm::V1'
  _globals['_QUERYACCOUNTREQUEST']._loaded_options = None
  _globals['_QUERYACCOUNTREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYCOSMOSACCOUNTREQUEST']._loaded_options = None
  _globals['_QUERYCOSMOSACCOUNTREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYVALIDATORACCOUNTREQUEST']._loaded_options = None
  _globals['_QUERYVALIDATORACCOUNTREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYBALANCEREQUEST']._loaded_options = None
  _globals['_QUERYBALANCEREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYSTORAGEREQUEST']._loaded_options = None
  _globals['_QUERYSTORAGEREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYCODEREQUEST']._loaded_options = None
  _globals['_QUERYCODEREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYTXLOGSREQUEST']._loaded_options = None
  _globals['_QUERYTXLOGSREQUEST']._serialized_options = b'\210\240\037\000\350\240\037\000'
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._loaded_options = None
  _globals['_QUERYPARAMSRESPONSE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_ETHCALLREQUEST'].fields_by_name['proposer_address']._loaded_options = None
  _globals['_ETHCALLREQUEST'].fields_by_name['proposer_address']._serialized_options = b'\372\336\037.github.com/cosmos/cosmos-sdk/types.ConsAddress'
  _globals['_QUERYTRACETXREQUEST'].fields_by_name['block_time']._loaded_options = None
  _globals['_QUERYTRACETXREQUEST'].fields_by_name['block_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_QUERYTRACETXREQUEST'].fields_by_name['proposer_address']._loaded_options = None
  _globals['_QUERYTRACETXREQUEST'].fields_by_name['proposer_address']._serialized_options = b'\372\336\037.github.com/cosmos/cosmos-sdk/types.ConsAddress'
  _globals['_QUERYTRACECALLREQUEST'].fields_by_name['proposer_address']._loaded_options = None
  _globals['_QUERYTRACECALLREQUEST'].fields_by_name['proposer_address']._serialized_options = b'\372\336\037.github.com/cosmos/cosmos-sdk/types.ConsAddress'
  _globals['_QUERYTRACECALLREQUEST'].fields_by_name['block_time']._loaded_options = None
  _globals['_QUERYTRACECALLREQUEST'].fields_by_name['block_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_QUERYTRACEBLOCKREQUEST'].fields_by_name['block_time']._loaded_options = None
  _globals['_QUERYTRACEBLOCKREQUEST'].fields_by_name['block_time']._serialized_options = b'\310\336\037\000\220\337\037\001'
  _globals['_QUERYTRACEBLOCKREQUEST'].fields_by_name['proposer_address']._loaded_options = None
  _globals['_QUERYTRACEBLOCKREQUEST'].fields_by_name['proposer_address']._serialized_options = b'\372\336\037.github.com/cosmos/cosmos-sdk/types.ConsAddress'
  _globals['_QUERYBASEFEERESPONSE'].fields_by_name['base_fee']._loaded_options = None
  _globals['_QUERYBASEFEERESPONSE'].fields_by_name['base_fee']._serialized_options = b'\332\336\037\025cosmossdk.io/math.Int'
  _globals['_QUERY'].methods_by_name['Account']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Account']._serialized_options = b'\202\323\344\223\002%\022#/injective/evm/v1/account/{address}'
  _globals['_QUERY'].methods_by_name['CosmosAccount']._loaded_options = None
  _globals['_QUERY'].methods_by_name['CosmosAccount']._serialized_options = b'\202\323\344\223\002,\022*/injective/evm/v1/cosmos_account/{address}'
  _globals['_QUERY'].methods_by_name['ValidatorAccount']._loaded_options = None
  _globals['_QUERY'].methods_by_name['ValidatorAccount']._serialized_options = b'\202\323\344\223\0024\0222/injective/evm/v1/validator_account/{cons_address}'
  _globals['_QUERY'].methods_by_name['Balance']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Balance']._serialized_options = b'\202\323\344\223\002&\022$/injective/evm/v1/balances/{address}'
  _globals['_QUERY'].methods_by_name['Storage']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Storage']._serialized_options = b'\202\323\344\223\002+\022)/injective/evm/v1/storage/{address}/{key}'
  _globals['_QUERY'].methods_by_name['Code']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Code']._serialized_options = b'\202\323\344\223\002#\022!/injective/evm/v1/codes/{address}'
  _globals['_QUERY'].methods_by_name['Params']._loaded_options = None
  _globals['_QUERY'].methods_by_name['Params']._serialized_options = b'\202\323\344\223\002\032\022\030/injective/evm/v1/params'
  _globals['_QUERY'].methods_by_name['EthCall']._loaded_options = None
  _globals['_QUERY'].methods_by_name['EthCall']._serialized_options = b'\202\323\344\223\002\034\022\032/injective/evm/v1/eth_call'
  _globals['_QUERY'].methods_by_name['EstimateGas']._loaded_options = None
  _globals['_QUERY'].methods_by_name['EstimateGas']._serialized_options = b'\202\323\344\223\002 \022\036/injective/evm/v1/estimate_gas'
  _globals['_QUERY'].methods_by_name['TraceTx']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TraceTx']._serialized_options = b'\202\323\344\223\002\034\022\032/injective/evm/v1/trace_tx'
  _globals['_QUERY'].methods_by_name['TraceBlock']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TraceBlock']._serialized_options = b'\202\323\344\223\002\037\022\035/injective/evm/v1/trace_block'
  _globals['_QUERY'].methods_by_name['TraceCall']._loaded_options = None
  _globals['_QUERY'].methods_by_name['TraceCall']._serialized_options = b'\202\323\344\223\002\036\022\034/injective/evm/v1/trace_call'
  _globals['_QUERY'].methods_by_name['BaseFee']._loaded_options = None
  _globals['_QUERY'].methods_by_name['BaseFee']._serialized_options = b'\202\323\344\223\002\034\022\032/injective/evm/v1/base_fee'
  _globals['_QUERYACCOUNTREQUEST']._serialized_start=302
  _globals['_QUERYACCOUNTREQUEST']._serialized_end=359
  _globals['_QUERYACCOUNTRESPONSE']._serialized_start=361
  _globals['_QUERYACCOUNTRESPONSE']._serialized_end=460
  _globals['_QUERYCOSMOSACCOUNTREQUEST']._serialized_start=462
  _globals['_QUERYCOSMOSACCOUNTREQUEST']._serialized_end=525
  _globals['_QUERYCOSMOSACCOUNTRESPONSE']._serialized_start=528
  _globals['_QUERYCOSMOSACCOUNTRESPONSE']._serialized_end=662
  _globals['_QUERYVALIDATORACCOUNTREQUEST']._serialized_start=664
  _globals['_QUERYVALIDATORACCOUNTREQUEST']._serialized_end=739
  _globals['_QUERYVALIDATORACCOUNTRESPONSE']._serialized_start=742
  _globals['_QUERYVALIDATORACCOUNTRESPONSE']._serialized_end=881
  _globals['_QUERYBALANCEREQUEST']._serialized_start=883
  _globals['_QUERYBALANCEREQUEST']._serialized_end=940
  _globals['_QUERYBALANCERESPONSE']._serialized_start=942
  _globals['_QUERYBALANCERESPONSE']._serialized_end=990
  _globals['_QUERYSTORAGEREQUEST']._serialized_start=992
  _globals['_QUERYSTORAGEREQUEST']._serialized_end=1067
  _globals['_QUERYSTORAGERESPONSE']._serialized_start=1069
  _globals['_QUERYSTORAGERESPONSE']._serialized_end=1113
  _globals['_QUERYCODEREQUEST']._serialized_start=1115
  _globals['_QUERYCODEREQUEST']._serialized_end=1169
  _globals['_QUERYCODERESPONSE']._serialized_start=1171
  _globals['_QUERYCODERESPONSE']._serialized_end=1210
  _globals['_QUERYTXLOGSREQUEST']._serialized_start=1212
  _globals['_QUERYTXLOGSREQUEST']._serialized_end=1334
  _globals['_QUERYTXLOGSRESPONSE']._serialized_start=1337
  _globals['_QUERYTXLOGSRESPONSE']._serialized_end=1474
  _globals['_QUERYPARAMSREQUEST']._serialized_start=1476
  _globals['_QUERYPARAMSREQUEST']._serialized_end=1496
  _globals['_QUERYPARAMSRESPONSE']._serialized_start=1498
  _globals['_QUERYPARAMSRESPONSE']._serialized_end=1575
  _globals['_ETHCALLREQUEST']._serialized_start=1578
  _globals['_ETHCALLREQUEST']._serialized_end=1791
  _globals['_ESTIMATEGASRESPONSE']._serialized_start=1793
  _globals['_ESTIMATEGASRESPONSE']._serialized_end=1877
  _globals['_QUERYTRACETXREQUEST']._serialized_start=1880
  _globals['_QUERYTRACETXREQUEST']._serialized_end=2360
  _globals['_QUERYTRACETXRESPONSE']._serialized_start=2362
  _globals['_QUERYTRACETXRESPONSE']._serialized_end=2404
  _globals['_QUERYTRACECALLREQUEST']._serialized_start=2407
  _globals['_QUERYTRACECALLREQUEST']._serialized_end=2798
  _globals['_QUERYTRACECALLRESPONSE']._serialized_start=2800
  _globals['_QUERYTRACECALLRESPONSE']._serialized_end=2844
  _globals['_QUERYTRACEBLOCKREQUEST']._serialized_start=2847
  _globals['_QUERYTRACEBLOCKREQUEST']._serialized_end=3245
  _globals['_QUERYTRACEBLOCKRESPONSE']._serialized_start=3247
  _globals['_QUERYTRACEBLOCKRESPONSE']._serialized_end=3292
  _globals['_QUERYBASEFEEREQUEST']._serialized_start=3294
  _globals['_QUERYBASEFEEREQUEST']._serialized_end=3315
  _globals['_QUERYBASEFEERESPONSE']._serialized_start=3317
  _globals['_QUERYBASEFEERESPONSE']._serialized_end=3393
  _globals['_QUERY']._serialized_start=3396
  _globals['_QUERY']._serialized_end=5178
# @@protoc_insertion_point(module_scope)



from typing import Any, Callable, Dict, Optional

from grpc.aio import Channel

from pyinjective.core.network import CookieAssistant
from pyinjective.proto.injective.tokenfactory.v1beta1 import (
    query_pb2 as token_factory_query_pb,
    query_pb2_grpc as token_factory_query_grpc,
)
from pyinjective.utils.grpc_api_request_assistant import GrpcApiRequestAssistant


class ChainGrpcTokenFactoryApi:
    def __init__(self, channel: Channel, cookie_assistant: CookieAssistant):
        self._query_stub = token_factory_query_grpc.QueryStub(channel)
        self._assistant = GrpcApiRequestAssistant(cookie_assistant=cookie_assistant)

    async def fetch_module_params(self) -> Dict[str, Any]:
        request = token_factory_query_pb.QueryParamsRequest()
        response = await self._execute_call(call=self._query_stub.Params, request=request)

        return response

    async def fetch_denom_authority_metadata(
        self,
        creator: str,
        sub_denom: Optional[str] = None,
    ) -> Dict[str, Any]:
        request = token_factory_query_pb.QueryDenomAuthorityMetadataRequest(
            creator=creator,
            sub_denom=sub_denom,
        )
        response = await self._execute_call(call=self._query_stub.DenomAuthorityMetadata, request=request)

        return response

    async def fetch_denoms_from_creator(self, creator: str) -> Dict[str, Any]:
        request = token_factory_query_pb.QueryDenomsFromCreatorRequest(creator=creator)
        response = await self._execute_call(call=self._query_stub.DenomsFromCreator, request=request)

        return response

    async def fetch_tokenfactory_module_state(self) -> Dict[str, Any]:
        request = token_factory_query_pb.QueryModuleStateRequest()
        response = await self._execute_call(call=self._query_stub.TokenfactoryModuleState, request=request)

        return response

    async def _execute_call(self, call: Callable, request) -> Dict[str, Any]:
        return await self._assistant.execute_call(call=call, request=request)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/tokenfactory/v1beta1/authorityMetadata.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6injective/tokenfactory/v1beta1/authorityMetadata.proto\x12\x1einjective.tokenfactory.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\"\x93\x01\n\x16\x44\x65nomAuthorityMetadata\x12&\n\x05\x61\x64min\x18\x01 \x01(\tB\x10\xf2\xde\x1f\x0cyaml:\"admin\"R\x05\x61\x64min\x12K\n\x12\x61\x64min_burn_allowed\x18\x02 \x01(\x08\x42\x1d\xf2\xde\x1f\x19yaml:\"admin_burn_allowed\"R\x10\x61\x64minBurnAllowed:\x04\xe8\xa0\x1f\x01\x42\xaa\x02\n\"com.injective.tokenfactory.v1beta1B\x16\x41uthorityMetadataProtoP\x01ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types\xa2\x02\x03ITX\xaa\x02\x1eInjective.Tokenfactory.V1beta1\xca\x02\x1eInjective\\Tokenfactory\\V1beta1\xe2\x02*Injective\\Tokenfactory\\V1beta1\\GPBMetadata\xea\x02 Injective::Tokenfactory::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.tokenfactory.v1beta1.authorityMetadata_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.injective.tokenfactory.v1beta1B\026AuthorityMetadataProtoP\001ZRgithub.com/InjectiveLabs/injective-core/injective-chain/modules/tokenfactory/types\242\002\003ITX\252\002\036Injective.Tokenfactory.V1beta1\312\002\036Injective\\Tokenfactory\\V1beta1\342\002*Injective\\Tokenfactory\\V1beta1\\GPBMetadata\352\002 Injective::Tokenfactory::V1beta1'
  _globals['_DENOMAUTHORITYMETADATA'].fields_by_name['admin']._loaded_options = None
  _globals['_DENOMAUTHORITYMETADATA'].fields_by_name['admin']._serialized_options = b'\362\336\037\014yaml:\"admin\"'
  _globals['_DENOMAUTHORITYMETADATA'].fields_by_name['admin_burn_allowed']._loaded_options = None
  _globals['_DENOMAUTHORITYMETADATA'].fields_by_name['admin_burn_allowed']._serialized_options = b'\362\336\037\031yaml:\"admin_burn_allowed\"'
  _globals['_DENOMAUTHORITYMETADATA']._loaded_options = None
  _globals['_DENOMAUTHORITYMETADATA']._serialized_options = b'\350\240\037\001'
  _globals['_DENOMAUTHORITYMETADATA']._serialized_start=145
  _globals['_DENOMAUTHORITYMETADATA']._serialized_end=292
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/oracle/v1beta1/oracle.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%injective/oracle/v1beta1/oracle.proto\x12\x18injective.oracle.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x11\x61mino/amino.proto\"E\n\x06Params\x12#\n\rpyth_contract\x18\x01 \x01(\tR\x0cpythContract:\x16\xe8\xa0\x1f\x01\x8a\xe7\xb0*\roracle/Params\"k\n\nOracleInfo\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x45\n\x0boracle_type\x18\x02 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\noracleType\"\xd6\x01\n\x13\x43hainlinkPriceState\x12\x17\n\x07\x66\x65\x65\x64_id\x18\x01 \x01(\tR\x06\x66\x65\x65\x64Id\x12;\n\x06\x61nswer\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x06\x61nswer\x12\x1c\n\ttimestamp\x18\x03 \x01(\x04R\ttimestamp\x12K\n\x0bprice_state\x18\x04 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00R\npriceState\"\xea\x01\n\x0e\x42\x61ndPriceState\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12\x31\n\x04rate\x18\x02 \x01(\tB\x1d\xc8\xde\x1f\x00\xda\xde\x1f\x15\x63osmossdk.io/math.IntR\x04rate\x12!\n\x0cresolve_time\x18\x03 \x01(\x04R\x0bresolveTime\x12\x1d\n\nrequest_ID\x18\x04 \x01(\x04R\trequestID\x12K\n\x0bprice_state\x18\x05 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00R\npriceState\"\x9d\x01\n\x0ePriceFeedState\x12\x12\n\x04\x62\x61se\x18\x01 \x01(\tR\x04\x62\x61se\x12\x14\n\x05quote\x18\x02 \x01(\tR\x05quote\x12\x45\n\x0bprice_state\x18\x03 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateR\npriceState\x12\x1a\n\x08relayers\x18\x04 \x03(\tR\x08relayers\"F\n\x0cProviderInfo\x12\x1a\n\x08provider\x18\x01 \x01(\tR\x08provider\x12\x1a\n\x08relayers\x18\x02 \x03(\tR\x08relayers\"\xbe\x01\n\rProviderState\x12K\n\rprovider_info\x18\x01 \x01(\x0b\x32&.injective.oracle.v1beta1.ProviderInfoR\x0cproviderInfo\x12`\n\x15provider_price_states\x18\x02 \x03(\x0b\x32,.injective.oracle.v1beta1.ProviderPriceStateR\x13providerPriceStates\"h\n\x12ProviderPriceState\x12\x16\n\x06symbol\x18\x01 \x01(\tR\x06symbol\x12:\n\x05state\x18\x02 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateR\x05state\"9\n\rPriceFeedInfo\x12\x12\n\x04\x62\x61se\x18\x01 \x01(\tR\x04\x62\x61se\x12\x14\n\x05quote\x18\x02 \x01(\tR\x05quote\"K\n\x0ePriceFeedPrice\x12\x39\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\"\xbb\x01\n\x12\x43oinbasePriceState\x12\x12\n\x04kind\x18\x01 \x01(\tR\x04kind\x12\x1c\n\ttimestamp\x18\x02 \x01(\x04R\ttimestamp\x12\x10\n\x03key\x18\x03 \x01(\tR\x03key\x12\x14\n\x05value\x18\x04 \x01(\x04R\x05value\x12K\n\x0bprice_state\x18\x05 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00R\npriceState\"\xcf\x01\n\x0fStorkPriceState\x12\x1c\n\ttimestamp\x18\x01 \x01(\x04R\ttimestamp\x12\x16\n\x06symbol\x18\x02 \x01(\tR\x06symbol\x12\x39\n\x05value\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05value\x12K\n\x0bprice_state\x18\x05 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00R\npriceState\"\xb5\x01\n\nPriceState\x12\x39\n\x05price\x18\x01 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12N\n\x10\x63umulative_price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0f\x63umulativePrice\x12\x1c\n\ttimestamp\x18\x03 \x01(\x03R\ttimestamp\"\xd6\x02\n\x0ePythPriceState\x12\x19\n\x08price_id\x18\x01 \x01(\tR\x07priceId\x12@\n\tema_price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08\x65maPrice\x12>\n\x08\x65ma_conf\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x07\x65maConf\x12\x37\n\x04\x63onf\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x04\x63onf\x12!\n\x0cpublish_time\x18\x05 \x01(\x04R\x0bpublishTime\x12K\n\x0bprice_state\x18\x06 \x01(\x0b\x32$.injective.oracle.v1beta1.PriceStateB\x04\xc8\xde\x1f\x00R\npriceState\"\x86\x03\n\x11\x42\x61ndOracleRequest\x12\x1d\n\nrequest_id\x18\x01 \x01(\x04R\trequestId\x12(\n\x10oracle_script_id\x18\x02 \x01(\x03R\x0eoracleScriptId\x12\x18\n\x07symbols\x18\x03 \x03(\tR\x07symbols\x12\x1b\n\task_count\x18\x04 \x01(\x04R\x08\x61skCount\x12\x1b\n\tmin_count\x18\x05 \x01(\x04R\x08minCount\x12h\n\tfee_limit\x18\x06 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.CoinsR\x08\x66\x65\x65Limit\x12\x1f\n\x0bprepare_gas\x18\x07 \x01(\x04R\nprepareGas\x12\x1f\n\x0b\x65xecute_gas\x18\x08 \x01(\x04R\nexecuteGas\x12(\n\x10min_source_count\x18\t \x01(\x04R\x0eminSourceCount\"\x86\x02\n\rBandIBCParams\x12(\n\x10\x62\x61nd_ibc_enabled\x18\x01 \x01(\x08R\x0e\x62\x61ndIbcEnabled\x12\x30\n\x14ibc_request_interval\x18\x02 \x01(\x03R\x12ibcRequestInterval\x12,\n\x12ibc_source_channel\x18\x03 \x01(\tR\x10ibcSourceChannel\x12\x1f\n\x0bibc_version\x18\x04 \x01(\tR\nibcVersion\x12\x1e\n\x0bibc_port_id\x18\x05 \x01(\tR\tibcPortId\x12*\n\x11legacy_oracle_ids\x18\x06 \x03(\x03R\x0flegacyOracleIds\"\x8f\x01\n\x14SymbolPriceTimestamp\x12<\n\x06oracle\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\x06oracle\x12\x1b\n\tsymbol_id\x18\x02 \x01(\tR\x08symbolId\x12\x1c\n\ttimestamp\x18\x03 \x01(\x03R\ttimestamp\"y\n\x13LastPriceTimestamps\x12\x62\n\x15last_price_timestamps\x18\x01 \x03(\x0b\x32..injective.oracle.v1beta1.SymbolPriceTimestampR\x13lastPriceTimestamps\"\xc2\x01\n\x0cPriceRecords\x12<\n\x06oracle\x18\x01 \x01(\x0e\x32$.injective.oracle.v1beta1.OracleTypeR\x06oracle\x12\x1b\n\tsymbol_id\x18\x02 \x01(\tR\x08symbolId\x12W\n\x14latest_price_records\x18\x03 \x03(\x0b\x32%.injective.oracle.v1beta1.PriceRecordR\x12latestPriceRecords\"f\n\x0bPriceRecord\x12\x1c\n\ttimestamp\x18\x01 \x01(\x03R\ttimestamp\x12\x39\n\x05price\x18\x02 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\"\xf3\x03\n\x12MetadataStatistics\x12\x1f\n\x0bgroup_count\x18\x01 \x01(\rR\ngroupCount\x12.\n\x13records_sample_size\x18\x02 \x01(\rR\x11recordsSampleSize\x12\x37\n\x04mean\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x04mean\x12\x37\n\x04twap\x18\x04 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x04twap\x12\'\n\x0f\x66irst_timestamp\x18\x05 \x01(\x03R\x0e\x66irstTimestamp\x12%\n\x0elast_timestamp\x18\x06 \x01(\x03R\rlastTimestamp\x12@\n\tmin_price\x18\x07 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08minPrice\x12@\n\tmax_price\x18\x08 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x08maxPrice\x12\x46\n\x0cmedian_price\x18\t \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x0bmedianPrice\"\xe1\x01\n\x10PriceAttestation\x12\x19\n\x08price_id\x18\x01 \x01(\tR\x07priceId\x12\x14\n\x05price\x18\x02 \x01(\x03R\x05price\x12\x12\n\x04\x63onf\x18\x03 \x01(\x04R\x04\x63onf\x12\x12\n\x04\x65xpo\x18\x04 \x01(\x05R\x04\x65xpo\x12\x1b\n\tema_price\x18\x05 \x01(\x03R\x08\x65maPrice\x12\x19\n\x08\x65ma_conf\x18\x06 \x01(\x04R\x07\x65maConf\x12\x19\n\x08\x65ma_expo\x18\x07 \x01(\x05R\x07\x65maExpo\x12!\n\x0cpublish_time\x18\x08 \x01(\x03R\x0bpublishTime\"}\n\tAssetPair\x12\x19\n\x08\x61sset_id\x18\x01 \x01(\tR\x07\x61ssetId\x12U\n\rsigned_prices\x18\x02 \x03(\x0b\x32\x30.injective.oracle.v1beta1.SignedPriceOfAssetPairR\x0csignedPrices\"\xb4\x01\n\x16SignedPriceOfAssetPair\x12#\n\rpublisher_key\x18\x01 \x01(\tR\x0cpublisherKey\x12\x1c\n\ttimestamp\x18\x02 \x01(\x04R\ttimestamp\x12\x39\n\x05price\x18\x03 \x01(\tB#\xc8\xde\x1f\x00\xda\xde\x1f\x1b\x63osmossdk.io/math.LegacyDecR\x05price\x12\x1c\n\tsignature\x18\x04 \x01(\x0cR\tsignature*\xaa\x01\n\nOracleType\x12\x0f\n\x0bUnspecified\x10\x00\x12\x08\n\x04\x42\x61nd\x10\x01\x12\r\n\tPriceFeed\x10\x02\x12\x0c\n\x08\x43oinbase\x10\x03\x12\r\n\tChainlink\x10\x04\x12\t\n\x05Razor\x10\x05\x12\x07\n\x03\x44ia\x10\x06\x12\x08\n\x04\x41PI3\x10\x07\x12\x07\n\x03Uma\x10\x08\x12\x08\n\x04Pyth\x10\t\x12\x0b\n\x07\x42\x61ndIBC\x10\n\x12\x0c\n\x08Provider\x10\x0b\x12\t\n\x05Stork\x10\x0c\x42\xff\x01\n\x1c\x63om.injective.oracle.v1beta1B\x0bOracleProtoP\x01ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\xa2\x02\x03IOX\xaa\x02\x18Injective.Oracle.V1beta1\xca\x02\x18Injective\\Oracle\\V1beta1\xe2\x02$Injective\\Oracle\\V1beta1\\GPBMetadata\xea\x02\x1aInjective::Oracle::V1beta1\xc0\xe3\x1e\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.oracle.v1beta1.oracle_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.injective.oracle.v1beta1B\013OracleProtoP\001ZLgithub.com/InjectiveLabs/injective-core/injective-chain/modules/oracle/types\242\002\003IOX\252\002\030Injective.Oracle.V1beta1\312\002\030Injective\\Oracle\\V1beta1\342\002$Injective\\Oracle\\V1beta1\\GPBMetadata\352\002\032Injective::Oracle::V1beta1\300\343\036\001'
  _globals['_PARAMS']._loaded_options = None
  _globals['_PARAMS']._serialized_options = b'\350\240\037\001\212\347\260*\roracle/Params'
  _globals['_CHAINLINKPRICESTATE'].fields_by_name['answer']._loaded_options = None
  _globals['_CHAINLINKPRICESTATE'].fields_by_name['answer']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_CHAINLINKPRICESTATE'].fields_by_name['price_state']._loaded_options = None
  _globals['_CHAINLINKPRICESTATE'].fields_by_name['price_state']._serialized_options = b'\310\336\037\000'
  _globals['_BANDPRICESTATE'].fields_by_name['rate']._loaded_options = None
  _globals['_BANDPRICESTATE'].fields_by_name['rate']._serialized_options = b'\310\336\037\000\332\336\037\025cosmossdk.io/math.Int'
  _globals['_BANDPRICESTATE'].fields_by_name['price_state']._loaded_options = None
  _globals['_BANDPRICESTATE'].fields_by_name['price_state']._serialized_options = b'\310\336\037\000'
  _globals['_PRICEFEEDPRICE'].fields_by_name['price']._loaded_options = None
  _globals['_PRICEFEEDPRICE'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_COINBASEPRICESTATE'].fields_by_name['price_state']._loaded_options = None
  _globals['_COINBASEPRICESTATE'].fields_by_name['price_state']._serialized_options = b'\310\336\037\000'
  _globals['_STORKPRICESTATE'].fields_by_name['value']._loaded_options = None
  _globals['_STORKPRICESTATE'].fields_by_name['value']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_STORKPRICESTATE'].fields_by_name['price_state']._loaded_options = None
  _globals['_STORKPRICESTATE'].fields_by_name['price_state']._serialized_options = b'\310\336\037\000'
  _globals['_PRICESTATE'].fields_by_name['price']._loaded_options = None
  _globals['_PRICESTATE'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PRICESTATE'].fields_by_name['cumulative_price']._loaded_options = None
  _globals['_PRICESTATE'].fields_by_name['cumulative_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PYTHPRICESTATE'].fields_by_name['ema_price']._loaded_options = None
  _globals['_PYTHPRICESTATE'].fields_by_name['ema_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PYTHPRICESTATE'].fields_by_name['ema_conf']._loaded_options = None
  _globals['_PYTHPRICESTATE'].fields_by_name['ema_conf']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PYTHPRICESTATE'].fields_by_name['conf']._loaded_options = None
  _globals['_PYTHPRICESTATE'].fields_by_name['conf']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_PYTHPRICESTATE'].fields_by_name['price_state']._loaded_options = None
  _globals['_PYTHPRICESTATE'].fields_by_name['price_state']._serialized_options = b'\310\336\037\000'
  _globals['_BANDORACLEREQUEST'].fields_by_name['fee_limit']._loaded_options = None
  _globals['_BANDORACLEREQUEST'].fields_by_name['fee_limit']._serialized_options = b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins'
  _globals['_PRICERECORD'].fields_by_name['price']._loaded_options = None
  _globals['_PRICERECORD'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_METADATASTATISTICS'].fields_by_name['mean']._loaded_options = None
  _globals['_METADATASTATISTICS'].fields_by_name['mean']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_METADATASTATISTICS'].fields_by_name['twap']._loaded_options = None
  _globals['_METADATASTATISTICS'].fields_by_name['twap']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_METADATASTATISTICS'].fields_by_name['min_price']._loaded_options = None
  _globals['_METADATASTATISTICS'].fields_by_name['min_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_METADATASTATISTICS'].fields_by_name['max_price']._loaded_options = None
  _globals['_METADATASTATISTICS'].fields_by_name['max_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_METADATASTATISTICS'].fields_by_name['median_price']._loaded_options = None
  _globals['_METADATASTATISTICS'].fields_by_name['median_price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_SIGNEDPRICEOFASSETPAIR'].fields_by_name['price']._loaded_options = None
  _globals['_SIGNEDPRICEOFASSETPAIR'].fields_by_name['price']._serialized_options = b'\310\336\037\000\332\336\037\033cosmossdk.io/math.LegacyDec'
  _globals['_ORACLETYPE']._serialized_start=4639
  _globals['_ORACLETYPE']._serialized_end=4809
  _globals['_PARAMS']._serialized_start=140
  _globals['_PARAMS']._serialized_end=209
  _globals['_ORACLEINFO']._serialized_start=211
  _globals['_ORACLEINFO']._serialized_end=318
  _globals['_CHAINLINKPRICESTATE']._serialized_start=321
  _globals['_CHAINLINKPRICESTATE']._serialized_end=535
  _globals['_BANDPRICESTATE']._serialized_start=538
  _globals['_BANDPRICESTATE']._serialized_end=772
  _globals['_PRICEFEEDSTATE']._serialized_start=775
  _globals['_PRICEFEEDSTATE']._serialized_end=932
  _globals['_PROVIDERINFO']._serialized_start=934
  _globals['_PROVIDERINFO']._serialized_end=1004
  _globals['_PROVIDERSTATE']._serialized_start=1007
  _globals['_PROVIDERSTATE']._serialized_end=1197
  _globals['_PROVIDERPRICESTATE']._serialized_start=1199
  _globals['_PROVIDERPRICESTATE']._serialized_end=1303
  _globals['_PRICEFEEDINFO']._serialized_start=1305
  _globals['_PRICEFEEDINFO']._serialized_end=1362
  _globals['_PRICEFEEDPRICE']._serialized_start=1364
  _globals['_PRICEFEEDPRICE']._serialized_end=1439
  _globals['_COINBASEPRICESTATE']._serialized_start=1442
  _globals['_COINBASEPRICESTATE']._serialized_end=1629
  _globals['_STORKPRICESTATE']._serialized_start=1632
  _globals['_STORKPRICESTATE']._serialized_end=1839
  _globals['_PRICESTATE']._serialized_start=1842
  _globals['_PRICESTATE']._serialized_end=2023
  _globals['_PYTHPRICESTATE']._serialized_start=2026
  _globals['_PYTHPRICESTATE']._serialized_end=2368
  _globals['_BANDORACLEREQUEST']._serialized_start=2371
  _globals['_BANDORACLEREQUEST']._serialized_end=2761
  _globals['_BANDIBCPARAMS']._serialized_start=2764
  _globals['_BANDIBCPARAMS']._serialized_end=3026
  _globals['_SYMBOLPRICETIMESTAMP']._serialized_start=3029
  _globals['_SYMBOLPRICETIMESTAMP']._serialized_end=3172
  _globals['_LASTPRICETIMESTAMPS']._serialized_start=3174
  _globals['_LASTPRICETIMESTAMPS']._serialized_end=3295
  _globals['_PRICERECORDS']._serialized_start=3298
  _globals['_PRICERECORDS']._serialized_end=3492
  _globals['_PRICERECORD']._serialized_start=3494
  _globals['_PRICERECORD']._serialized_end=3596
  _globals['_METADATASTATISTICS']._serialized_start=3599
  _globals['_METADATASTATISTICS']._serialized_end=4098
  _globals['_PRICEATTESTATION']._serialized_start=4101
  _globals['_PRICEATTESTATION']._serialized_end=4326
  _globals['_ASSETPAIR']._serialized_start=4328
  _globals['_ASSETPAIR']._serialized_end=4453
  _globals['_SIGNEDPRICEOFASSETPAIR']._serialized_start=4456
  _globals['_SIGNEDPRICEOFASSETPAIR']._serialized_end=4636
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cometbft/libs/bits/v1/types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!cometbft/libs/bits/v1/types.proto\x12\x15\x63ometbft.libs.bits.v1\"4\n\x08\x42itArray\x12\x12\n\x04\x62its\x18\x01 \x01(\x03R\x04\x62its\x12\x14\n\x05\x65lems\x18\x02 \x03(\x04R\x05\x65lemsB\xd6\x01\n\x19\x63om.cometbft.libs.bits.v1B\nTypesProtoP\x01Z6github.com/cometbft/cometbft/api/cometbft/libs/bits/v1\xa2\x02\x03\x43LB\xaa\x02\x15\x43ometbft.Libs.Bits.V1\xca\x02\x15\x43ometbft\\Libs\\Bits\\V1\xe2\x02!Cometbft\\Libs\\Bits\\V1\\GPBMetadata\xea\x02\x18\x43ometbft::Libs::Bits::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cometbft.libs.bits.v1.types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\031com.cometbft.libs.bits.v1B\nTypesProtoP\001Z6github.com/cometbft/cometbft/api/cometbft/libs/bits/v1\242\002\003CLB\252\002\025Cometbft.Libs.Bits.V1\312\002\025Cometbft\\Libs\\Bits\\V1\342\002!Cometbft\\Libs\\Bits\\V1\\GPBMetadata\352\002\030Cometbft::Libs::Bits::V1'
  _globals['_BITARRAY']._serialized_start=60
  _globals['_BITARRAY']._serialized_end=112
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/evm/v1/genesis.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.injective.evm.v1 import params_pb2 as injective_dot_evm_dot_v1_dot_params__pb2
from pyinjective.proto.injective.evm.v1 import state_pb2 as injective_dot_evm_dot_v1_dot_state__pb2
from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1einjective/evm/v1/genesis.proto\x12\x10injective.evm.v1\x1a\x1dinjective/evm/v1/params.proto\x1a\x1cinjective/evm/v1/state.proto\x1a\x14gogoproto/gogo.proto\"\x8a\x01\n\x0cGenesisState\x12\x42\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32 .injective.evm.v1.GenesisAccountB\x04\xc8\xde\x1f\x00R\x08\x61\x63\x63ounts\x12\x36\n\x06params\x18\x02 \x01(\x0b\x32\x18.injective.evm.v1.ParamsB\x04\xc8\xde\x1f\x00R\x06params\"\x82\x01\n\x0eGenesisAccount\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x12\n\x04\x63ode\x18\x02 \x01(\tR\x04\x63ode\x12\x42\n\x07storage\x18\x03 \x03(\x0b\x32\x17.injective.evm.v1.StateB\x0f\xc8\xde\x1f\x00\xaa\xdf\x1f\x07StorageR\x07storageB\xd1\x01\n\x14\x63om.injective.evm.v1B\x0cGenesisProtoP\x01ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\xa2\x02\x03IEX\xaa\x02\x10Injective.Evm.V1\xca\x02\x10Injective\\Evm\\V1\xe2\x02\x1cInjective\\Evm\\V1\\GPBMetadata\xea\x02\x12Injective::Evm::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.evm.v1.genesis_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.injective.evm.v1B\014GenesisProtoP\001ZIgithub.com/InjectiveLabs/injective-core/injective-chain/modules/evm/types\242\002\003IEX\252\002\020Injective.Evm.V1\312\002\020Injective\\Evm\\V1\342\002\034Injective\\Evm\\V1\\GPBMetadata\352\002\022Injective::Evm::V1'
  _globals['_GENESISSTATE'].fields_by_name['accounts']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['accounts']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISSTATE'].fields_by_name['params']._loaded_options = None
  _globals['_GENESISSTATE'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_GENESISACCOUNT'].fields_by_name['storage']._loaded_options = None
  _globals['_GENESISACCOUNT'].fields_by_name['storage']._serialized_options = b'\310\336\037\000\252\337\037\007Storage'
  _globals['_GENESISSTATE']._serialized_start=136
  _globals['_GENESISSTATE']._serialized_end=274
  _globals['_GENESISACCOUNT']._serialized_start=277
  _globals['_GENESISACCOUNT']._serialized_end=407
# @@protoc_insertion_point(module_scope)



import asyncio
import json
import os

import aiohttp

OFAC_LIST_URL = (
    "https://raw.githubusercontent.com/InjectiveLabs/injective-lists/"
    "refs/heads/master/json/wallets/ofacAndRestricted.json"
)
OFAC_LIST_FILENAME_DEFAULT = "ofac.json"
OFAC_LIST_FILENAME = OFAC_LIST_FILENAME_DEFAULT


class OfacChecker:
    def __init__(self):
        self._ofac_list_path = self.get_ofac_list_path()
        try:
            with open(self._ofac_list_path, "r") as f:
                self._ofac_list = set(json.load(f))
        except Exception as e:
            raise Exception(
                f"Error parsing OFAC list. Please, download it by running python3 pyinjective/ofac_list.py ({e})"
            )

    @classmethod
    def get_ofac_list_path(cls):
        return os.path.join(os.path.dirname(__file__), OFAC_LIST_FILENAME)

    @classmethod
    async def download_ofac_list(cls):
        async with aiohttp.ClientSession() as session:
            try:
                async with session.get(OFAC_LIST_URL) as response:
                    response.raise_for_status()
                    text_content = await response.text()
                    ofac_list = json.loads(text_content)
                    ofac_file_path = cls.get_ofac_list_path()
                    with open(ofac_file_path, "w") as f:
                        json.dump(ofac_list, f, indent=2)
                        f.write("\n")
                    return
            except Exception as e:
                raise Exception(f"Error fetching OFAC list: {e}")

    def is_blacklisted(self, address: str) -> bool:
        return address in self._ofac_list


async def main():
    await OfacChecker.download_ofac_list()


if __name__ == "__main__":
    asyncio.run(main())



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from pyinjective.proto.injective.erc20.v1beta1 import query_pb2 as injective_dot_erc20_dot_v1beta1_dot_query__pb2


class QueryStub(object):
    """Query defines the gRPC querier service.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Params = channel.unary_unary(
                '/injective.erc20.v1beta1.Query/Params',
                request_serializer=injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
                response_deserializer=injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
                _registered_method=True)
        self.AllTokenPairs = channel.unary_unary(
                '/injective.erc20.v1beta1.Query/AllTokenPairs',
                request_serializer=injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryAllTokenPairsRequest.SerializeToString,
                response_deserializer=injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryAllTokenPairsResponse.FromString,
                _registered_method=True)
        self.TokenPairByDenom = channel.unary_unary(
                '/injective.erc20.v1beta1.Query/TokenPairByDenom',
                request_serializer=injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryTokenPairByDenomRequest.SerializeToString,
                response_deserializer=injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryTokenPairByDenomResponse.FromString,
                _registered_method=True)
        self.TokenPairByERC20Address = channel.unary_unary(
                '/injective.erc20.v1beta1.Query/TokenPairByERC20Address',
                request_serializer=injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryTokenPairByERC20AddressRequest.SerializeToString,
                response_deserializer=injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryTokenPairByERC20AddressResponse.FromString,
                _registered_method=True)


class QueryServicer(object):
    """Query defines the gRPC querier service.
    """

    def Params(self, request, context):
        """Params defines a gRPC query method that returns the erc20 module's
        parameters.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AllTokenPairs(self, request, context):
        """AllTokenPairs defines a gRPC query method that returns the erc20
        module's created token pairs.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TokenPairByDenom(self, request, context):
        """TokenPairByDenom defines a gRPC query method that returns the erc20
        module's token pair associated with the provided bank denom.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TokenPairByERC20Address(self, request, context):
        """TokenPairByERC20Address defines a gRPC query method that returns the erc20
        module's token pair associated with the provided erc20 contract address.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QueryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Params': grpc.unary_unary_rpc_method_handler(
                    servicer.Params,
                    request_deserializer=injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryParamsRequest.FromString,
                    response_serializer=injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryParamsResponse.SerializeToString,
            ),
            'AllTokenPairs': grpc.unary_unary_rpc_method_handler(
                    servicer.AllTokenPairs,
                    request_deserializer=injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryAllTokenPairsRequest.FromString,
                    response_serializer=injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryAllTokenPairsResponse.SerializeToString,
            ),
            'TokenPairByDenom': grpc.unary_unary_rpc_method_handler(
                    servicer.TokenPairByDenom,
                    request_deserializer=injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryTokenPairByDenomRequest.FromString,
                    response_serializer=injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryTokenPairByDenomResponse.SerializeToString,
            ),
            'TokenPairByERC20Address': grpc.unary_unary_rpc_method_handler(
                    servicer.TokenPairByERC20Address,
                    request_deserializer=injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryTokenPairByERC20AddressRequest.FromString,
                    response_serializer=injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryTokenPairByERC20AddressResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'injective.erc20.v1beta1.Query', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('injective.erc20.v1beta1.Query', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class Query(object):
    """Query defines the gRPC querier service.
    """

    @staticmethod
    def Params(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.erc20.v1beta1.Query/Params',
            injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryParamsRequest.SerializeToString,
            injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryParamsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AllTokenPairs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.erc20.v1beta1.Query/AllTokenPairs',
            injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryAllTokenPairsRequest.SerializeToString,
            injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryAllTokenPairsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TokenPairByDenom(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.erc20.v1beta1.Query/TokenPairByDenom',
            injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryTokenPairByDenomRequest.SerializeToString,
            injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryTokenPairByDenomResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def TokenPairByERC20Address(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/injective.erc20.v1beta1.Query/TokenPairByERC20Address',
            injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryTokenPairByERC20AddressRequest.SerializeToString,
            injective_dot_erc20_dot_v1beta1_dot_query__pb2.QueryTokenPairByERC20AddressResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: injective/permissions/v1beta1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from pyinjective.proto.cosmos.base.v1beta1 import coin_pb2 as cosmos_dot_base_dot_v1beta1_dot_coin__pb2
from pyinjective.proto.cosmos.bank.v1beta1 import bank_pb2 as cosmos_dot_bank_dot_v1beta1_dot_bank__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.injective.permissions.v1beta1 import params_pb2 as injective_dot_permissions_dot_v1beta1_dot_params__pb2
from pyinjective.proto.injective.permissions.v1beta1 import permissions_pb2 as injective_dot_permissions_dot_v1beta1_dot_permissions__pb2
from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&injective/permissions/v1beta1/tx.proto\x12\x1dinjective.permissions.v1beta1\x1a\x14gogoproto/gogo.proto\x1a\x1e\x63osmos/base/v1beta1/coin.proto\x1a\x1e\x63osmos/bank/v1beta1/bank.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a*injective/permissions/v1beta1/params.proto\x1a/injective/permissions/v1beta1/permissions.proto\x1a\x11\x61mino/amino.proto\"\xbe\x01\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x43\n\x06params\x18\x02 \x01(\x0b\x32%.injective.permissions.v1beta1.ParamsB\x04\xc8\xde\x1f\x00R\x06params:.\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*\x1bpermissions/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse\"\xbd\x01\n\x12MsgCreateNamespace\x12)\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"R\x06sender\x12L\n\tnamespace\x18\x02 \x01(\x0b\x32(.injective.permissions.v1beta1.NamespaceB\x04\xc8\xde\x1f\x00R\tnamespace:.\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1epermissions/MsgCreateNamespace\"\x1c\n\x1aMsgCreateNamespaceResponse\"\x8c\x05\n\x12MsgUpdateNamespace\x12)\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"R\x06sender\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom\x12\x66\n\rcontract_hook\x18\x03 \x01(\x0b\x32\x41.injective.permissions.v1beta1.MsgUpdateNamespace.SetContractHookR\x0c\x63ontractHook\x12N\n\x10role_permissions\x18\x04 \x03(\x0b\x32#.injective.permissions.v1beta1.RoleR\x0frolePermissions\x12O\n\rrole_managers\x18\x05 \x03(\x0b\x32*.injective.permissions.v1beta1.RoleManagerR\x0croleManagers\x12T\n\x0fpolicy_statuses\x18\x06 \x03(\x0b\x32+.injective.permissions.v1beta1.PolicyStatusR\x0epolicyStatuses\x12v\n\x1bpolicy_manager_capabilities\x18\x07 \x03(\x0b\x32\x36.injective.permissions.v1beta1.PolicyManagerCapabilityR\x19policyManagerCapabilities\x1a.\n\x0fSetContractHook\x12\x1b\n\tnew_value\x18\x01 \x01(\tR\x08newValue:.\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1epermissions/MsgUpdateNamespace\"\x1c\n\x1aMsgUpdateNamespaceResponse\"\xbd\x02\n\x13MsgUpdateActorRoles\x12)\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"R\x06sender\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom\x12V\n\x12role_actors_to_add\x18\x03 \x03(\x0b\x32).injective.permissions.v1beta1.RoleActorsR\x0froleActorsToAdd\x12\\\n\x15role_actors_to_revoke\x18\x05 \x03(\x0b\x32).injective.permissions.v1beta1.RoleActorsR\x12roleActorsToRevoke:/\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1fpermissions/MsgUpdateActorRoles\"\x1d\n\x1bMsgUpdateActorRolesResponse\"\x7f\n\x0fMsgClaimVoucher\x12)\n\x06sender\x18\x01 \x01(\tB\x11\xf2\xde\x1f\ryaml:\"sender\"R\x06sender\x12\x14\n\x05\x64\x65nom\x18\x02 \x01(\tR\x05\x64\x65nom:+\x82\xe7\xb0*\x06sender\x8a\xe7\xb0*\x1bpermissions/MsgClaimVoucher\"\x19\n\x17MsgClaimVoucherResponse2\x83\x05\n\x03Msg\x12v\n\x0cUpdateParams\x12..injective.permissions.v1beta1.MsgUpdateParams\x1a\x36.injective.permissions.v1beta1.MsgUpdateParamsResponse\x12\x7f\n\x0f\x43reateNamespace\x12\x31.injective.permissions.v1beta1.MsgCreateNamespace\x1a\x39.injective.permissions.v1beta1.MsgCreateNamespaceResponse\x12\x7f\n\x0fUpdateNamespace\x12\x31.injective.permissions.v1beta1.MsgUpdateNamespace\x1a\x39.injective.permissions.v1beta1.MsgUpdateNamespaceResponse\x12\x82\x01\n\x10UpdateActorRoles\x12\x32.injective.permissions.v1beta1.MsgUpdateActorRoles\x1a:.injective.permissions.v1beta1.MsgUpdateActorRolesResponse\x12v\n\x0c\x43laimVoucher\x12..injective.permissions.v1beta1.MsgClaimVoucher\x1a\x36.injective.permissions.v1beta1.MsgClaimVoucherResponse\x1a\x05\x80\xe7\xb0*\x01\x42\x95\x02\n!com.injective.permissions.v1beta1B\x07TxProtoP\x01ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/permissions/types\xa2\x02\x03IPX\xaa\x02\x1dInjective.Permissions.V1beta1\xca\x02\x1dInjective\\Permissions\\V1beta1\xe2\x02)Injective\\Permissions\\V1beta1\\GPBMetadata\xea\x02\x1fInjective::Permissions::V1beta1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'injective.permissions.v1beta1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n!com.injective.permissions.v1beta1B\007TxProtoP\001ZQgithub.com/InjectiveLabs/injective-core/injective-chain/modules/permissions/types\242\002\003IPX\252\002\035Injective.Permissions.V1beta1\312\002\035Injective\\Permissions\\V1beta1\342\002)Injective\\Permissions\\V1beta1\\GPBMetadata\352\002\037Injective::Permissions::V1beta1'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*\033permissions/MsgUpdateParams'
  _globals['_MSGCREATENAMESPACE'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGCREATENAMESPACE'].fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _globals['_MSGCREATENAMESPACE'].fields_by_name['namespace']._loaded_options = None
  _globals['_MSGCREATENAMESPACE'].fields_by_name['namespace']._serialized_options = b'\310\336\037\000'
  _globals['_MSGCREATENAMESPACE']._loaded_options = None
  _globals['_MSGCREATENAMESPACE']._serialized_options = b'\202\347\260*\006sender\212\347\260*\036permissions/MsgCreateNamespace'
  _globals['_MSGUPDATENAMESPACE'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGUPDATENAMESPACE'].fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _globals['_MSGUPDATENAMESPACE']._loaded_options = None
  _globals['_MSGUPDATENAMESPACE']._serialized_options = b'\202\347\260*\006sender\212\347\260*\036permissions/MsgUpdateNamespace'
  _globals['_MSGUPDATEACTORROLES'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGUPDATEACTORROLES'].fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _globals['_MSGUPDATEACTORROLES']._loaded_options = None
  _globals['_MSGUPDATEACTORROLES']._serialized_options = b'\202\347\260*\006sender\212\347\260*\037permissions/MsgUpdateActorRoles'
  _globals['_MSGCLAIMVOUCHER'].fields_by_name['sender']._loaded_options = None
  _globals['_MSGCLAIMVOUCHER'].fields_by_name['sender']._serialized_options = b'\362\336\037\ryaml:\"sender\"'
  _globals['_MSGCLAIMVOUCHER']._loaded_options = None
  _globals['_MSGCLAIMVOUCHER']._serialized_options = b'\202\347\260*\006sender\212\347\260*\033permissions/MsgClaimVoucher'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._serialized_start=324
  _globals['_MSGUPDATEPARAMS']._serialized_end=514
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=516
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=541
  _globals['_MSGCREATENAMESPACE']._serialized_start=544
  _globals['_MSGCREATENAMESPACE']._serialized_end=733
  _globals['_MSGCREATENAMESPACERESPONSE']._serialized_start=735
  _globals['_MSGCREATENAMESPACERESPONSE']._serialized_end=763
  _globals['_MSGUPDATENAMESPACE']._serialized_start=766
  _globals['_MSGUPDATENAMESPACE']._serialized_end=1418
  _globals['_MSGUPDATENAMESPACE_SETCONTRACTHOOK']._serialized_start=1324
  _globals['_MSGUPDATENAMESPACE_SETCONTRACTHOOK']._serialized_end=1370
  _globals['_MSGUPDATENAMESPACERESPONSE']._serialized_start=1420
  _globals['_MSGUPDATENAMESPACERESPONSE']._serialized_end=1448
  _globals['_MSGUPDATEACTORROLES']._serialized_start=1451
  _globals['_MSGUPDATEACTORROLES']._serialized_end=1768
  _globals['_MSGUPDATEACTORROLESRESPONSE']._serialized_start=1770
  _globals['_MSGUPDATEACTORROLESRESPONSE']._serialized_end=1799
  _globals['_MSGCLAIMVOUCHER']._serialized_start=1801
  _globals['_MSGCLAIMVOUCHER']._serialized_end=1928
  _globals['_MSGCLAIMVOUCHERRESPONSE']._serialized_start=1930
  _globals['_MSGCLAIMVOUCHERRESPONSE']._serialized_end=1955
  _globals['_MSG']._serialized_start=1958
  _globals['_MSG']._serialized_end=2601
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cosmos/consensus/v1/tx.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from pyinjective.proto.amino import amino_pb2 as amino_dot_amino__pb2
from pyinjective.proto.cosmos_proto import cosmos_pb2 as cosmos__proto_dot_cosmos__pb2
from pyinjective.proto.cosmos.msg.v1 import msg_pb2 as cosmos_dot_msg_dot_v1_dot_msg__pb2
from pyinjective.proto.cometbft.types.v1 import params_pb2 as cometbft_dot_types_dot_v1_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x63osmos/consensus/v1/tx.proto\x12\x13\x63osmos.consensus.v1\x1a\x11\x61mino/amino.proto\x1a\x19\x63osmos_proto/cosmos.proto\x1a\x17\x63osmos/msg/v1/msg.proto\x1a\x1e\x63ometbft/types/v1/params.proto\"\xec\x03\n\x0fMsgUpdateParams\x12\x36\n\tauthority\x18\x01 \x01(\tB\x18\xd2\xb4-\x14\x63osmos.AddressStringR\tauthority\x12\x34\n\x05\x62lock\x18\x02 \x01(\x0b\x32\x1e.cometbft.types.v1.BlockParamsR\x05\x62lock\x12=\n\x08\x65vidence\x18\x03 \x01(\x0b\x32!.cometbft.types.v1.EvidenceParamsR\x08\x65vidence\x12@\n\tvalidator\x18\x04 \x01(\x0b\x32\".cometbft.types.v1.ValidatorParamsR\tvalidator\x12\x31\n\x04\x61\x62\x63i\x18\x05 \x01(\x0b\x32\x1d.cometbft.types.v1.ABCIParamsR\x04\x61\x62\x63i\x12@\n\tsynchrony\x18\x06 \x01(\x0b\x32\".cometbft.types.v1.SynchronyParamsR\tsynchrony\x12:\n\x07\x66\x65\x61ture\x18\x07 \x01(\x0b\x32 .cometbft.types.v1.FeatureParamsR\x07\x66\x65\x61ture:9\x82\xe7\xb0*\tauthority\x8a\xe7\xb0*&cosmos-sdk/x/consensus/MsgUpdateParams\"\x19\n\x17MsgUpdateParamsResponse2p\n\x03Msg\x12\x62\n\x0cUpdateParams\x12$.cosmos.consensus.v1.MsgUpdateParams\x1a,.cosmos.consensus.v1.MsgUpdateParamsResponse\x1a\x05\x80\xe7\xb0*\x01\x42\xc0\x01\n\x17\x63om.cosmos.consensus.v1B\x07TxProtoP\x01Z.github.com/cosmos/cosmos-sdk/x/consensus/types\xa2\x02\x03\x43\x43X\xaa\x02\x13\x43osmos.Consensus.V1\xca\x02\x13\x43osmos\\Consensus\\V1\xe2\x02\x1f\x43osmos\\Consensus\\V1\\GPBMetadata\xea\x02\x15\x43osmos::Consensus::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'cosmos.consensus.v1.tx_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\027com.cosmos.consensus.v1B\007TxProtoP\001Z.github.com/cosmos/cosmos-sdk/x/consensus/types\242\002\003CCX\252\002\023Cosmos.Consensus.V1\312\002\023Cosmos\\Consensus\\V1\342\002\037Cosmos\\Consensus\\V1\\GPBMetadata\352\002\025Cosmos::Consensus::V1'
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._loaded_options = None
  _globals['_MSGUPDATEPARAMS'].fields_by_name['authority']._serialized_options = b'\322\264-\024cosmos.AddressString'
  _globals['_MSGUPDATEPARAMS']._loaded_options = None
  _globals['_MSGUPDATEPARAMS']._serialized_options = b'\202\347\260*\tauthority\212\347\260*&cosmos-sdk/x/consensus/MsgUpdateParams'
  _globals['_MSG']._loaded_options = None
  _globals['_MSG']._serialized_options = b'\200\347\260*\001'
  _globals['_MSGUPDATEPARAMS']._serialized_start=157
  _globals['_MSGUPDATEPARAMS']._serialized_end=649
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_start=651
  _globals['_MSGUPDATEPARAMSRESPONSE']._serialized_end=676
  _globals['_MSG']._serialized_start=678
  _globals['_MSG']._serialized_end=790
# @@protoc_insertion_point(module_scope)
